/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __LAUNCHER_INTERFACE_H__
#define __LAUNCHER_INTERFACE_H__

#include <string>
#include <functional>

namespace tizen {
namespace runtime {

class LauncherInterface
{
	public:
		virtual int initialize(bool standalone) = 0;
		virtual void dispose() = 0;
		virtual int runManagedLauncher(const char* appId, const char* appBase, const char* tpaList) = 0;
		virtual int launch(const char* appId, const char* root, const char* path, int argc, char* argv[]) = 0;
};

struct AppInfo {
	std::string root;
	std::string path;
	std::string id;
	std::string pkg;
	std::string type;
};

class LaunchpadAdapter
{
	public:
		virtual void loaderMain(int argc, char* argv[]) = 0;
		std::function<void()> onCreate = nullptr;
		std::function<void(const AppInfo&, int, char**)> onLaunch = nullptr;
		std::function<void(const AppInfo&, int, char**)> onTerminate = nullptr;
};

extern LaunchpadAdapter& Launchpad;

}  // namespace runtime
}  // namespace tizen

#endif /* __LAUNCHER_INTERFACE_H__ */
